@@ -4,10 +4,10 @@
 #'
 #' @param x A numeric vector of values
 #' @param left,right Boundary values
-#' @param type Abbreviation for the evaluation of `left` on `right` (see details)
+#' @param type Abbreviation for the evaluation of `left` on `right` (see
+#'   details)
 #'
-#' @details
-#' Type can be one of the below:
+#' @details Type can be one of the below:
 #'
 #' \describe{
 #'  \item{g}{is greater than (>)}
@@ -28,8 +28,8 @@
 between_more <- function(x, left, right, type = c("gele", "gel", "gle", "gl")) {
   type <- match_param(type)
 
-  if (any(left > right)) {
-    warning("`left` > `right`", call. = FALSE)
+  if (any(left > right, na.rm = TRUE)) {
+    warning(cond_between_more_lr())
   }
 
   switch(
@@ -40,3 +40,14 @@ between_more <- function(x, left, right, type = c("gele", "gel", "gle", "gl")) {
     gl   = x > left & x < right
   )
 }
+
+
+# conditions --------------------------------------------------------------
+
+cond_between_more_lr <- function() {
+  new_condition(
+    "`left` > `right`",
+    "between_more_lr",
+    type = "warning"
+  )
+}
