@@ -50,7 +50,6 @@ remove_na.factor <- function(x) {
 #' @rdname remove_na
 #' @export
 remove_na.fact <- function(x) {
-  # browser()
   x <- fact_na(x, remove = TRUE)
   at <- attributes(x)
   x <- x[!is.na(x)]
@@ -93,10 +92,7 @@ omit_na <- function(x) {
 #' remove_null(x)
 #' @export
 remove_null <- function(x) {
-  if (!inherits(x, "list")) {
-    stop("x must be a list", call. = FALSE)
-  }
-
+  stopifnot(inherits(x, "list"))
   x[!vap_lgl(x, is.null)]
 }
 
@@ -104,43 +100,34 @@ remove_null <- function(x) {
 #'
 #' Select or remove columns that are entirely NA
 #'
-#' @param x A data.frame
+#' @param x A `data.frame`
 #' @param names Logical, if `TRUE` (default) will return column names as names
 #'   of vector
 #'
 #' @returns
-#' * `select_na_cols()` the data.frame with only columns that are all `NA`
-#' * `remove_na_cols()` the data.frame without columns of only `NA`
+#' * `select_na_cols()` `x` with only columns that are all `NA`
+#' * `remove_na_cols()` `x` without columns of only `NA`
 #' * `is_na_cols()` a logical vector: `TRUE` all rows of column are `NA`,
 #'  otherwise `FALSE`
 #' @name na_cols
+NULL
+
+#' @rdname na_cols
 #' @export
-
 select_na_cols <- function(x) {
-  if (!is.data.frame(x)) {
-    stop("x must be a data.frame", call. = FALSE)
-  }
-
-  x[, is_na_cols(x)]
+  x[, is_na_cols(x), drop = FALSE]
 }
 
 #' @rdname na_cols
 #' @export
 remove_na_cols <- function(x) {
-  if (!is.data.frame(x)) {
-    stop("x must be a data.frame", call. = FALSE)
-  }
-
-  x[, !is_na_cols(x)]
+  x[, !is_na_cols(x), drop = FALSE]
 }
 
 #' @rdname na_cols
 #' @export
 is_na_cols <- function(x, names = TRUE) {
-  if (!is.data.frame(x)) {
-    stop("x must be a data.frame", call. = FALSE)
-  }
-
+  stopifnot(is.data.frame(x))
   vap_lgl(x, function(xx) all(is.na(xx)), .nm = names)
 }
 
@@ -166,7 +153,7 @@ is_na_cols <- function(x, names = TRUE) {
 #' tableNA(x[1], x[2])
 #' tableNA(x[1], x[2], x[3]) # equivalent ot tableNA(x, .list = TRUE)
 
-tableNA <- function(..., .list = FALSE) {
+tableNA <- function(..., .list = FALSE) { # nolint: object_name_linter
   ls <- if (.list) {
     as.list(...)
   } else {
