@@ -114,7 +114,10 @@ switch_in_case <- function(x, ..., .default = NULL, .envir = parent.frame()) {
     )
   }
 
-  rhs <- lapply(splits, function(i) eval(parse(text = i[2L]), envir = parent.frame()))
+  rhs <- lapply(splits, function(i)  {
+    eval(parse(text = i[2L]), envir = parent.frame())
+  })
+
   lhs <- lapply(splits, function(i) {
     # A bit more intensive to deal with "1:Inf" and what not
     res <- try_catch_inf(eval(parse(text = i[1L]), envir = .envir))
@@ -125,28 +128,25 @@ switch_in_case <- function(x, ..., .default = NULL, .envir = parent.frame()) {
     cres <- as.character(res)
     if (cres[1L] == ":") {
       if (!exists("xrange")) {
-        stop(
-          "x did not appear to be numeric,",
-          "cannot continue evaluating lhs", call. = FALSE
-        )
+        stop(cond_switch_in_case_numeric())
       }
+
       cres[cres == "-Inf"] <- xrange[1L]
       cres[cres == "Inf"] <- xrange[2L]
       if (any(cres %in% c("-Inf", "inf"))) {
-        stop("Ambiguous infinity, cannot calculate", call. = FALSE)
+        stop(cond_switch_in_case_ambiguous())
       }
     }
 
     tryCatch(
       do.call(cres[1L], as.list(cres[-1L])),
       error = function(e) {
-        stop("Could not evaluate lhs\n", e$message, call. = FALSE)
+        stop(cond_switch_in_case_evaluate(e$message))
       }
     )
   })
 
   # set the default NA value
-  # res0 <- .default %||% rhs[[1L]][0L][NA]
   res0 <- .default %||% NA
 
   do_switches <- function(xi) {
@@ -169,9 +169,9 @@ switch_in_case <- function(x, ..., .default = NULL, .envir = parent.frame()) {
     resi
   }
 
-  # debugonce(do_switches)
   res <- lapply(x, do_switches)
   stopifnot(lengths(res) == 1L)
+  res <- unlist(res)
   mode(res) <- mode(res[[1]])
   class(res) <- class(res[[1]])
   names(res) <- x
@@ -233,21 +233,24 @@ switch_length_check <- function(ls) {
     length(u),
     return(ls),
     {
-      if (u[1L] == 0L)
-        stop("Cannot have 0 length rhs", call. = FALSE)
+      if (u[1L] == 0L) {
+        stop(cond_switch_length_check_0())
+      }
 
       if (u[1L] == 1L) {
         ind <- which(lens == 1L)
+
         for (i in ind) {
           ls[[i]] <- rep.int(ls[[i]], u[2L])
         }
+
         return(ls)
       }
-      stop("2 lengths found, one of which was not 1", call. = FALSE)
+      stop(cond_switch_length_check_2())
     },
-    stop("3 or more lengths found, stopping", call. = FALSE)
+    stop(cond_switch_length_check_3())
   )
-  stop("Something really went wrong", call. = FALSE)
+  stop(cond_switch_length_check_bad())
 }
 
 switch_lengths_check <- function(lhs, rhs) {
@@ -259,8 +262,56 @@ switch_lengths_check <- function(lhs, rhs) {
   }
 
   if (!identical(llens, rlens)) {
-    stop("statements have different lengths", call. = FALSE)
+    stop(cond_switch_lengths_check())
   }
 
   return(invisible(NULL))
 }
+
+# conditions --------------------------------------------------------------
+
+cond_switch_in_case_numeric <- function() {
+  new_condition(
+    "x did not appear to be numeric, cannot continue evaluating lhs",
+    "switch_in_case_numeric"
+  )
+}
+
+cond_switch_in_case_ambiguous <- function() {
+  new_condition(
+    "Ambiguous infinity, cannot calculate",
+    "switch_in_case_ambiguous"
+  )
+}
+
+cond_switch_in_case_evaluate <- function(x) {
+  new_condition(
+    paste0("Could not evaluate lhs\n", x),
+    "switch_in_case_evaluate"
+  )
+}
+
+cond_switch_lengths_check <- function() {
+  new_condition("statements have different lengths", "switch_lengths_check")
+}
+
+cond_switch_length_check_0 <- function() {
+  new_condition("Cannot have 0 length rhs", "switch_length_check_0")
+}
+
+cond_switch_length_check_2 <- function() {
+  new_condition(
+    "2 lengths found, one of which was not 1",
+    "switch_length_check_1"
+  )
+}
+
+cond_switch_length_check_3 <- function() {
+  new_condition("3 or more lengths found, stopping", "switch_length_check_3")
+}
+
+cond_switch_length_check_bad <- function() {
+  new_condition("Something really went wrong", "switch_length_check_bad")
+}
+
+# terminal line
