@@ -7,7 +7,7 @@ test_that("details() works", {
   expect_error(detail(x), NA)
   expect_error(detail(df), NA)
 
-  expect_error(detail(data.frame()))
+  expect_error(detail(data.frame()), class = "detailDataFrameListError")
 
   exp <- quick_dfl(
     class   = "logical",
@@ -36,7 +36,10 @@ test_that("details() and tibbles", {
 
   expect_error(detail(tibble::tibble(a = 1, b = 1:3)), NA)
   expect_error(detail(tibble::tibble(a = 1, b = list(1:3))), NA)
-  expect_error(detail(tibble::tibble(a = NULL, b = list(1:3))))
+  expect_error(
+    detail(tibble::tibble(a = NULL, b = list(1:3))),
+    class = "detailDataFrameListError"
+  )
 })
 
 test_that("details.data.frame() passes with single column [48]", {
